@@ -9,12 +9,13 @@ import (
 )
 
 //NewConfigGenerator create a config generator for a given collector type
-func NewConfigGenerator(collector logging.LogCollectionType, includeLegacyForwardConfig, includeLegacySyslogConfig bool) (ConfigGenerator, error) {
+func NewConfigGenerator(collector logging.LogCollectionType, includeLegacyForwardConfig, includeLegacySyslogConfig, useOldRemoteSyslogPlugin bool) (ConfigGenerator, error) {
 	switch collector {
 	case logging.LogCollectionTypeFluentd:
-		return fluentd.NewConfigGenerator(includeLegacyForwardConfig, includeLegacySyslogConfig)
+		return fluentd.NewConfigGenerator(includeLegacyForwardConfig, includeLegacySyslogConfig, useOldRemoteSyslogPlugin)
+	default:
+		return nil, fmt.Errorf("Config generation not supported for collectors of type %s", collector)
 	}
-	return nil, fmt.Errorf("Config generation not supported for collects of type %s", collector)
 }
 
 //ConfigGenerator is a config generator for a given ForwardingSpec
